@@ -37,17 +37,10 @@ typedef enum
 	CL_STYLE_GLOSSY = 1,
 	CL_STYLE_INVERTED = 2,
 	CL_STYLE_GUMMY = 3,
-	CL_NUM_STYLES = 4
+	CL_STYLE_GNOME3 = 4,
+	CL_NUM_STYLES = 5
 } ClearlooksStyles;
 
-typedef enum
-{
-	CL_STATE_NORMAL,
-	CL_STATE_ACTIVE,
-	CL_STATE_SELECTED,
-	CL_STATE_INSENSITIVE
-} ClearlooksStateType;
-
 typedef enum
 {
 	CL_JUNCTION_NONE      = 0,
@@ -189,7 +182,7 @@ typedef struct
 
 	gfloat  radius;
 	
-	ClearlooksStateType state_type;
+	GtkStateType state_type;
 	
 	uint8 corners;
 	uint8 xthickness;
@@ -300,6 +293,18 @@ typedef struct
 	boolean              in_menu;
 } CheckboxParameters;
 
+typedef struct
+{
+	/* The maximum size of the fill. Calcualted from the entries allocation,
+	 * and other information. Relative to the drawn position.
+	 */
+	GdkRectangle max_size;
+	gboolean max_size_known;
+	/* The border around the bar. This can be used for radius calculations.
+	 */
+	GtkBorder border;
+} EntryProgressParameters;
+
 typedef struct
 {
 	ClearlooksArrowType type;
@@ -358,6 +363,13 @@ struct _ClearlooksStyleFunctions
 	void (*draw_entry)            (cairo_t *cr,
 	                               const ClearlooksColors *colors,
 	                               const WidgetParameters *widget,
+	                               const FocusParameters  *focus,
+	                               int x, int y, int width, int height);
+
+	void (*draw_entry_progress)   (cairo_t *cr,
+	                               const ClearlooksColors *colors,
+	                               const WidgetParameters *widget,
+	                               const EntryProgressParameters *progress,
 	                               int x, int y, int width, int height);
 
 	void (*draw_spinbutton)       (cairo_t *cr,
